==> cramr_ui_lib-0.0.11.tar.gz: lib/routes/verb_studymode_selection_route.dart <==
import 'package:cramr_ui_lib/model/study_mode.dart';
import 'package:cramr_ui_lib/routes/verb_indicative_study_cover_mode_route.dart';
import 'package:cramr_ui_lib/routes/verb_indicative_study_flashcard_mode_route.dart';
import 'package:cramr_ui_lib/routes/verb_indicative_study_write_mode_route.dart';
import 'package:cramr_ui_lib/settings/settings_controller.dart';
import 'package:cramr_ui_lib/settings/settings_view.dart';
import 'package:cramr_ui_lib/theme/custom_theme.dart';
import 'package:flutter/cupertino.dart';
import 'package:flutter/material.dart';

/// The route for selecting the Study Mode
class VerbStudymodeSelectionRoute extends StatelessWidget {
  static const routeName = '/verbStudymodeSelectionRoute';

  final SettingsController _settingsController;

  const VerbStudymodeSelectionRoute(this._settingsController, {Key? key})
      : super(key: key);

  @override
  Widget build(BuildContext context) {
    return AnimatedBuilder(
      animation: _settingsController,
      builder: (BuildContext context, Widget? child) {
        return MaterialApp(
          debugShowCheckedModeBanner: false,
          themeMode: _settingsController.themeMode,
          theme: CustomTheme.lightTheme,
          darkTheme: ThemeData.dark(),
          home: SafeArea(
              child: Scaffold(
                appBar: AppBar(
                  actions: [_settingsIcon(context)],
                ),
                body: Center(
                  key: const Key('StudyModeSelection'),
                  child: ListView(
                    children: [
                      InkWell(
                        key: const Key('buttonCoverMode'),
                        child: _buildCard('afdekken', Icons.view_headline_sharp),
                        onTap: () {
                          _launchNextRoute(context, StudyMode.coverMode);
                        },
                      ),
                      InkWell(
                        key: const Key('buttonFlashCardMode'),
                        child: _buildCard('kaartjes', Icons.style_outlined),
                        onTap: () {
                          _launchNextRoute(context, StudyMode.flashCardMode);
                        },
                      ),
                      InkWell(
                        key: const Key('buttonWriteMode'),
                        child: _buildCard('schrijven', Icons.app_registration),
                        onTap: () {
                          _launchNextRoute(context, StudyMode.writtenMode);
                        },
                      )
                    ],
                  ),
                ),
              )),
        );
      }
    );
  }

  void _launchNextRoute(BuildContext context, StudyMode studyMode) {
    Navigator.restorablePopAndPushNamed(context, _routeName(studyMode));
  }

  Card _buildCard(String modeName, IconData iconData) {
    return Card(
      margin: const EdgeInsets.fromLTRB(30, 15, 30, 15),
      child: ListTile(
        key: UniqueKey(),
        title: Column(
          key: UniqueKey(),
          mainAxisAlignment: MainAxisAlignment.center,
          crossAxisAlignment: CrossAxisAlignment.center,
          children: [
            Padding(
              key: UniqueKey(),
              padding: const EdgeInsets.fromLTRB(10, 10, 10, 10),
              child: Text(
                modeName,
                key: UniqueKey(),
                style: CustomTheme.lightTheme.textTheme.headline1,
              ),
            ),
            Padding(
              padding: const EdgeInsets.fromLTRB(10, 10, 10, 10),
              child: Icon(
                iconData,
                key: UniqueKey(),
                color: CustomTheme.lightTheme.textTheme.headline1!.color,
                size: 50.0,
              ),
            ),
          ],
        ),
      ),
      elevation: 20,
    );
  }

  String _routeName(StudyMode studyMode) {
    switch (studyMode) {
      case StudyMode.coverMode:
        return VerbIndicativeStudyCoverModeRoute.routeName;
      case StudyMode.flashCardMode:
        return VerbIndicativeStudyFlashcardModeRoute.routeName;
      case StudyMode.writtenMode:
        return VerbIndicativeStudyWriteModeRoute.routeName;
    }
  }

  IconButton _settingsIcon(BuildContext context) {
    return IconButton(
        icon: const Icon(Icons.settings),
        onPressed: () {
          Navigator.restorablePushNamed(context, SettingsView.routeName);
        });
  }
}

==> cramr_ui_lib-0.0.17.tar.gz: lib/routes/verb_studymode_selection_route.dart <==
import 'package:cramr_ui_lib/model/study_mode.dart';
import 'package:cramr_ui_lib/routes/verb_indicative_study_cover_mode_route.dart';
import 'package:cramr_ui_lib/routes/verb_indicative_study_flashcard_mode_route.dart';
import 'package:cramr_ui_lib/routes/verb_indicative_study_write_mode_route.dart';
import 'package:cramr_ui_lib/settings/settings_controller.dart';
import 'package:cramr_ui_lib/settings/settings_view.dart';
import 'package:cramr_ui_lib/theme/custom_theme.dart';
import 'package:flutter/cupertino.dart';
import 'package:flutter/material.dart';

/// The route for selecting the Study Mode
class VerbStudymodeSelectionRoute extends StatelessWidget {
  static const routeName = '/verbStudymodeSelectionRoute';

  final SettingsController _settingsController;

  const VerbStudymodeSelectionRoute(this._settingsController, {Key? key})
      : super(key: key);

  @override
  Widget build(BuildContext context) {
    return AnimatedBuilder(
        animation: _settingsController,
        builder: (BuildContext context, Widget? child) {
          return MaterialApp(
            debugShowCheckedModeBanner: false,
            themeMode: _settingsController.themeMode,
            theme: CustomTheme.lightTheme,
            darkTheme: ThemeData.dark(),
            home: SafeArea(
                child: Scaffold(
              appBar: AppBar(
                actions: [_settingsIcon(context)],
              ),
              body: Center(
                key: const Key('StudyModeSelection'),
                child: ListView(
                  children: [
                    InkWell(
                      key: const Key('buttonCoverMode'),
                      child: _buildCard('afdekken', Icons.view_headline_sharp),
                      onTap: () {
                        _launchNextRoute(context, StudyMode.coverMode);
                      },
                    ),
                    InkWell(
                      key: const Key('buttonFlashCardMode'),
                      child: _buildCard('kaartjes', Icons.style_outlined),
                      onTap: () {
                        _launchNextRoute(context, StudyMode.flashCardMode);
                      },
                    ),
                    InkWell(
                      key: const Key('buttonWriteMode'),
                      child: _buildCard('schrijven', Icons.app_registration),
                      onTap: () {
                        _launchNextRoute(context, StudyMode.writtenMode);
                      },
                    )
                  ],
                ),
              ),
            )),
          );
        });
  }

  void _launchNextRoute(BuildContext context, StudyMode studyMode) {
    Navigator.restorablePopAndPushNamed(context, _routeName(studyMode));
  }

  Card _buildCard(String modeName, IconData iconData) {
    return Card(
      margin: const EdgeInsets.fromLTRB(30, 15, 30, 15),
      child: ListTile(
        key: UniqueKey(),
        title: Column(
          key: UniqueKey(),
          mainAxisAlignment: MainAxisAlignment.center,
          crossAxisAlignment: CrossAxisAlignment.center,
          children: [
            Padding(
              key: UniqueKey(),
              padding: const EdgeInsets.fromLTRB(10, 10, 10, 10),
              child: Text(
                modeName,
                key: UniqueKey(),
                style: CustomTheme.lightTheme.textTheme.headline1,
              ),
            ),
            Padding(
              padding: const EdgeInsets.fromLTRB(10, 10, 10, 10),
              child: Icon(
                iconData,
                key: UniqueKey(),
                color: CustomTheme.lightTheme.textTheme.headline1!.color,
                size: 50.0,
              ),
            ),
          ],
        ),
      ),
      elevation: 20,
    );
  }

  String _routeName(StudyMode studyMode) {
    switch (studyMode) {
      case StudyMode.coverMode:
        return VerbIndicativeStudyCoverModeRoute.routeName;
      case StudyMode.flashCardMode:
        return VerbIndicativeStudyFlashcardModeRoute.routeName;
      case StudyMode.writtenMode:
        return VerbIndicativeStudyWriteModeRoute.routeName;
    }
  }

  IconButton _settingsIcon(BuildContext context) {
    return IconButton(
        key: const Key('settingsButton'),
        icon: const Icon(Icons.settings),
        onPressed: () {
          Navigator.pushNamed(context, SettingsView.routeName);
        });
  }
}
